@@ -1,17 +1,21 @@
-import click, os
+import click, os, shutil
 from . import cli, echo_error, get_config
 
 
 @cli.command(context_settings={"ignore_unknown_options": True})
-@click.argument("action")
+@click.argument("action", type=click.Choice(['release', 'debug', 'watch']))
 @click.argument("name", default="")
 @click.argument("additional_args", nargs=-1)
 def flare(action, name, additional_args):
-    """build or watch a flare fontend"""
+    """build or watch a flare frontend"""
     projectConfig = get_config()
     additional_args = list(additional_args)
 
     if action == "release":
+        if shutil.which("zip") is None:
+            echo_error(f'Please install "zip" to bundle a flare application.')
+            return
+
         additional_args = ["-mzc"]
     elif action == "debug":
         pass
